Module init

Module init 

Package initialization and scaffolding for aipm-pack init.

Creates a new plugin directory with an aipm.toml manifest and conventional directory layout based on the plugin type.

Structs

Options
Options for initializing a new plugin package.

Enums

Error
Errors specific to the init command.

Functions

init
Initialize a new plugin package in the given directory.