pub fn init(opts: &Options<'_>, fs: &dyn Fs) -> Result<(), Error>Expand description
Initialize a new plugin package in the given directory.
Errors
Returns Error if the directory already contains an aipm.toml,
the package name is invalid, or I/O operations fail.